``glom`` Tutorial
=================

*Learn to use glom in 10 minutes or less!*

Basic use of glom requires only a glance, not a whole tutorial. The
case study below takes a wider look at day-to-day data and object
manipulation, helping you develop an eye for writing robust,
declarative data transformations.

.. contents:: Contents
   :local:

.. automodule:: glom.tutorial
